
:autogenerated:

krotov.shapes module
====================

.. currentmodule:: krotov.shapes

.. automodule:: krotov.shapes
    :members: blackman, box, flattop, one_shape, qutip_callback, zero_shape
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Functions:

    .. autosummary::
        :nosignatures:

        blackman
        box
        flattop
        one_shape
        qutip_callback
        zero_shape





    ``__all__``: :func:`blackman <krotov.shapes.blackman>`, :func:`box <krotov.shapes.box>`, :func:`flattop <krotov.shapes.flattop>`, :func:`one_shape <krotov.shapes.one_shape>`, :func:`qutip_callback <krotov.shapes.qutip_callback>`, :func:`zero_shape <krotov.shapes.zero_shape>`



    Reference
    ---------